@@ -1,10 +1,11 @@
 package Pod::Weaver::Section::Completion::GetoptLongComplete;
 
-our $DATE = '2014-12-07'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-01-13'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use Moose;
+with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 with 'Pod::Weaver::Role::SectionText::SelfCompletion';
 
@@ -44,15 +45,7 @@ sub weave_section {
 
     my $text = $self->section_text({command_name=>$command_name});
 
-    $document->children->push(
-        Pod::Elemental::Element::Nested->new({
-            command  => 'head1',
-            content  => 'COMPLETION',
-            children => [
-                map { s/\n/ /g; Pod::Elemental::Element::Pod5::Ordinary->new({ content => $_ })} split /\n\n/, $text
-            ],
-        }),
-    );
+    $self->add_text_to_section($document, $text, 'COMPLETION');
 }
 
 no Moose;
@@ -71,7 +64,7 @@ Pod::Weaver::Section::Completion::GetoptLongComplete - Add a COMPLETION section
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2014-12-07.
+This document describes version 0.06 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2015-01-13.
 
 =head1 SYNOPSIS
 
@@ -113,7 +106,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
